use strict;
use warnings;
use Test::More;

# generated by Dist::Zilla::Plugin::Test::PodSpelling 2.006008
use Test::Spelling 0.12;
use Pod::Wordlist;


add_stopwords(<DATA>);
all_pod_files_spelling_ok( qw( bin lib  ) );
__DATA__
Num
Str
datetime
merchantID
ip
cid
CVN
cvc
cvv
login
SOAPI
Bleue
Carta
Carte
Dankort
JAL
Santander
UATP
YYYY
timestamp
Overmeer
AVS
MerchantReferenceCode
env
WSDL
XSD
subclasses
auth
dcc
GüdTech
HostGator
faultstring
faultcode
Caleb
Cushing
xenoterracide
Carl
Carstenson
ccarstenson
Lantz
carl
Robert
Stone
robertstone
lib
Business
CyberSource
Client
Exception
AttributeIsRequiredNotToBeSet
ItemsOrTotal
NotACreditCard
Response
SOAPFault
UnableToDetectCardTypeCode
Factory
Request
Rule
Message
MessagePart
AuthReversal
Authorization
Capture
Credit
DCC
FollowOnCredit
Role
BillingInfo
CreditCardInfo
TaxService
Sale
StandAloneCredit
RequestPart
BillTo
BusinessRules
Card
Item
PurchaseTotals
Service
Tax
Amount
AuthCode
Base
ElectronicVerification
ProcessorResponse
ReasonCode
ReconciliationID
RequestDateTime
ResponsePart
AuthReply
DCCReply
Reply
TaxReply
Currency
ForeignCurrency
Traceable
ExpiredCard
RequestIDisZero
MooseX
Types
